# -*- coding: utf-8 -*-
from setuphelpers import *


appx_package = "Microsoft.MicrosoftStickyNotes"
appx_dir = makepath(programfiles, "WindowsAppsInstallers")
windows_min_os_version = WindowsVersions.Windows10v1607
allow_remove = False


def install():
    # Declaring local variables
    bin_name = glob.glob("%s*%s*" % (appx_package, control.get_software_version()))[0]
    bin_path = makepath(appx_dir, bin_name)

    # Checking minimum Windows version for this UWP application
    if windows_version() >= windows_min_os_version:
        if not isdir(appx_dir):
            mkdirs(appx_dir)
        else:
            for appx_file in glob.glob(makepath(appx_dir, "%s*%s*" % (appx_package, control.get_software_version()))):
                if not control.get_software_version() in appx_file:
                    remove_file(appx_file)
        if not isfile(bin_path):
            print("Copying: %s to: %s" % (bin_name, appx_dir))
            filecopyto(bin_name, appx_dir)
    else:
        error(
            "This Windows version (%s) need to be upgraded to minimum version (%s) to use this package" % (windows_version(), windows_min_os_version)
        )


def session_setup():
    # Declaring local variables
    bin_path = glob.glob(makepath(appx_dir, "%s*%s*" % (appx_package, control.get_software_version())))[0]

    # Installing the software in user env
    appx_version = get_powershell_str("Get-AppxPackage -Name %s" % appx_package, "Version")
    if not appx_version or appx_version < control.get_software_version() or force:
        print("Installing: %s" % bin_path.split("\\")[-1])
        run_powershell('Add-AppxPackage -Path "%s"' % bin_path)
    else:
        print("%s is installed in correct version (%s)" % (appx_package, appx_version))


def uninstall():
    if allow_remove:
        remove_appx(appx_package)
    for appx_file in glob.glob(makepath(appx_dir, "%s*%s*" % (appx_package, control.get_software_version()))):
        remove_file(appx_file)
    if isdir(appx_dir) and dir_is_empty(appx_dir):
        print("Removing: %s since he is empty" % (appx_dir))
        remove_tree(appx_dir)
